package com.wy.work;

package ..deTemp.1740017265393;

import com.wy.service.v3.DeduceInfoV3ApiService;
import com.wy.service.v3.InfoFileImportV3ApiService;
import com.wy.utils.RedisUtil;
import jakarta.annotation.Resource;
import java.util.concurrent.TimeUnit;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

@Configuration
@EnableScheduling
public class CacheWork {
  private static final Logger log = LoggerFactory.getLogger(com.wy.work.CacheWork.class);
  
  @Resource
  InfoFileImportV3ApiService infoFileImportV3ApiService;
  
  @Resource
  private DeduceInfoV3ApiService deduceInfoV3ApiService;
  
  @Resource
  private RedisUtil redisUtil;
  
  @Scheduled(cron = "${infofileimport.cron}")
  public void infofileimportCron() {
    Long start = Long.valueOf(System.currentTimeMillis());
    log.info("开始情报文档导入自动识别");
    this.infoFileImportV3ApiService.identify();
    log.info("结束情报文档导入自动识别，耗时: {}", Long.valueOf(System.currentTimeMillis() - start.longValue()));
  }
  
  @Scheduled(cron = "${deduce.auto_create_cron}")
  public void autoCreateDeduceTask() {
    String lockKey = "LOCK:autoCreateDeduceTask";
    try {
      boolean processing = this.redisUtil.lock(lockKey, Integer.valueOf(10), TimeUnit.MINUTES);
      if (!processing) {
        log.info("自动创建推演模型任务处理中....");
        return;
      } 
      Long start = Long.valueOf(System.currentTimeMillis());
      log.info("开始自动创建推演模型任务");
      this.deduceInfoV3ApiService.autoCreateTask();
      log.info("结束自动创建推演模型任务，耗时: {}", Long.valueOf(System.currentTimeMillis() - start.longValue()));
      this.redisUtil.unlock(lockKey);
    } catch (Exception e) {
      e.printStackTrace();
      this.redisUtil.unlock(lockKey);
    } 
  }
  
  @Scheduled(cron = "${deduce.auto_deduce_cron}")
  public void autoDeduceTask() {
    String lockKey = "LOCK:autoDeduceTask";
    try {
      boolean processing = this.redisUtil.lock(lockKey, Integer.valueOf(10), TimeUnit.MINUTES);
      if (!processing) {
        log.info("自动推演任务处理中....");
        return;
      } 
      Long start = Long.valueOf(System.currentTimeMillis());
      log.info("开始自动推演任务");
      this.deduceInfoV3ApiService.autoDeduceTask();
      log.info("结束自动推演任务，耗时: {}", Long.valueOf(System.currentTimeMillis() - start.longValue()));
      this.redisUtil.unlock(lockKey);
    } catch (Exception e) {
      e.printStackTrace();
      this.redisUtil.unlock(lockKey);
    } 
  }
  
  @Scheduled(cron = "${deduce.auto_deduce_result_cron}")
  public void autoDeduceResultTask() {
    String lockKey = "LOCK:autoDeduceResultTask";
    try {
      boolean processing = this.redisUtil.lock(lockKey, Integer.valueOf(10), TimeUnit.MINUTES);
      if (!processing) {
        log.info("自动推演结果整理任务处理中....");
        return;
      } 
      Long start = Long.valueOf(System.currentTimeMillis());
      log.info("开始自动推演结果整理任务");
      this.deduceInfoV3ApiService.autoDeduceResultTask();
      log.info("结束自动推演结果整理任务，耗时: {}", Long.valueOf(System.currentTimeMillis() - start.longValue()));
      this.redisUtil.unlock(lockKey);
    } catch (Exception e) {
      e.printStackTrace();
      this.redisUtil.unlock(lockKey);
    } 
  }
}
